kicost.currency\_converter package
==================================

Submodules
----------

kicost.currency\_converter.currency\_converter module
-----------------------------------------------------

.. automodule:: kicost.currency_converter.currency_converter
   :members:
   :undoc-members:
   :show-inheritance:

kicost.currency\_converter.currency\_tables module
--------------------------------------------------

.. automodule:: kicost.currency_converter.currency_tables
   :members:
   :undoc-members:
   :show-inheritance:

kicost.currency\_converter.default\_rates module
------------------------------------------------

.. automodule:: kicost.currency_converter.default_rates
   :members:
   :undoc-members:
   :show-inheritance:

kicost.currency\_converter.download\_rates module
-------------------------------------------------

.. automodule:: kicost.currency_converter.download_rates
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: kicost.currency_converter
   :members:
   :undoc-members:
   :show-inheritance:
